@@ -5,7 +5,7 @@ use SMS::Send::Driver ();
 use LWP::UserAgent ();
 use HTTP::Cookies ();
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 our @ISA = 'SMS::Send::Driver';
 
@@ -127,9 +127,7 @@ SMS::Send::IS::Vit - SMS::Send driver for vit.is
 =head1 DESCRIPTION
 
 A regional L<SMS::Send> driver for Iceland that deliers messages via
-L<http://vit.is>. Vit only supports ending sms messages to
-SE<iacute>minn users, see L<SMS::Send::IS::Vodafone> for sending SMS
-to Vodafone users.
+L<http://vit.is> to any Icelandic cell phone number.
 
 =head1 CAVEATS
 
@@ -137,6 +135,10 @@ This module will call C<sleep(1)> when it first retrieves a cookie
 before it submits the sms. The vit.is server does not seem to
 recognize a cookie it handed out until after a slight delay.
 
+=head1 SEE ALSO
+
+L<SMS::Send::IS::Vodafone>
+
 =head1 AUTHOR
 
 E<AElig>var ArnfjE<ouml>rE<eth> Bjarmason <avar@cpan.org>
